@@ -13,7 +13,7 @@ try:
     from astropy import units as u
     from astropy.coordinates import Angle, SkyCoord, EarthLocation, AltAz, ICRS
 except ImportError:
-    Time = None
+    pass
 
 __all__ = ["radec2azel", "azel2radec"]
 
@@ -24,8 +24,6 @@ def azel2radec(
     lat_deg: float,
     lon_deg: float,
     time: datetime,
-    *,
-    use_astropy: bool = True
 ) -> tuple[float, float]:
     """
     viewing angle (az, el) to sky coordinates (ra, dec)
@@ -42,8 +40,6 @@ def azel2radec(
               observer longitude [-180, 180] (degrees)
     time : datetime.datetime or str
            time of observation
-    use_astropy : bool, optional
-                 default use astropy.
 
     Returns
     -------
@@ -53,7 +49,7 @@ def azel2radec(
          ecliptic declination (degrees)
     """
 
-    if use_astropy and Time is not None:
+    try:
 
         obs = EarthLocation(lat=lat_deg * u.deg, lon=lon_deg * u.deg)
 
@@ -64,8 +60,8 @@ def azel2radec(
         sky = SkyCoord(direc.transform_to(ICRS()))
 
         return sky.ra.deg, sky.dec.deg
-
-    return vazel2radec(az_deg, el_deg, lat_deg, lon_deg, time)
+    except NameError:
+        return vazel2radec(az_deg, el_deg, lat_deg, lon_deg, time)
 
 
 def radec2azel(
@@ -74,8 +70,6 @@ def radec2azel(
     lat_deg: float,
     lon_deg: float,
     time: datetime,
-    *,
-    use_astropy: bool = False
 ) -> tuple[float, float]:
     """
     sky coordinates (ra, dec) to viewing angle (az, el)
@@ -92,8 +86,6 @@ def radec2azel(
               observer longitude [-180, 180] (degrees)
     time : datetime.datetime or str
            time of observation
-    use_astropy : bool, optional
-                 default use astropy.
 
     Returns
     -------
@@ -103,11 +95,11 @@ def radec2azel(
              elevation [degrees above horizon (neglecting aberration)]
     """
 
-    if use_astropy and Time is not None:
+    try:
         obs = EarthLocation(lat=lat_deg * u.deg, lon=lon_deg * u.deg)
         points = SkyCoord(Angle(ra_deg, unit=u.deg), Angle(dec_deg, unit=u.deg), equinox="J2000.0")
         altaz = points.transform_to(AltAz(location=obs, obstime=Time(str2dt(time))))
 
         return altaz.az.degree, altaz.alt.degree
-
-    return vradec2azel(ra_deg, dec_deg, lat_deg, lon_deg, time)
+    except NameError:
+        return vradec2azel(ra_deg, dec_deg, lat_deg, lon_deg, time)
