@@ -1,26 +1,21 @@
 """ transforms involving ENU East North Up """
 from __future__ import annotations
-import typing
 
 from math import tau
 
 try:
-    from numpy import asarray, radians, sin, cos, hypot, arctan2 as atan2, degrees
+    from numpy import asarray
 except ImportError:
-    from math import radians, sin, cos, hypot, atan2, degrees  # type: ignore
+    pass
 
 from .ecef import geodetic2ecef, ecef2geodetic, enu2ecef, uvw2enu
 from .ellipsoid import Ellipsoid
-
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
+from .mathfun import radians, sin, cos, hypot, atan2, degrees
 
 __all__ = ["enu2aer", "aer2enu", "enu2geodetic", "geodetic2enu"]
 
 
-def enu2aer(
-    e: ndarray, n: ndarray, u: ndarray, deg: bool = True
-) -> tuple[ndarray, ndarray, ndarray]:
+def enu2aer(e, n, u, deg: bool = True) -> tuple:
     """
     ENU to Azimuth, Elevation, Range
 
@@ -73,9 +68,7 @@ def enu2aer(
     return az, elev, slantRange
 
 
-def aer2enu(
-    az: ndarray, el: ndarray, srange: float | ndarray, deg: bool = True
-) -> tuple[ndarray, ndarray, ndarray]:
+def aer2enu(az, el, srange, deg: bool = True) -> tuple:
     """
     Azimuth, Elevation, Slant range to target to East, North, Up
 
@@ -116,15 +109,15 @@ def aer2enu(
 
 
 def enu2geodetic(
-    e: ndarray,
-    n: ndarray,
-    u: ndarray,
-    lat0: ndarray,
-    lon0: ndarray,
-    h0: ndarray,
+    e,
+    n,
+    u,
+    lat0,
+    lon0,
+    h0,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[ndarray, ndarray, ndarray]:
+) -> tuple:
     """
     East, North, Up to target to geodetic coordinates
 
@@ -164,15 +157,15 @@ def enu2geodetic(
 
 
 def geodetic2enu(
-    lat: ndarray,
-    lon: ndarray,
-    h: ndarray,
-    lat0: ndarray,
-    lon0: ndarray,
-    h0: ndarray,
+    lat,
+    lon,
+    h,
+    lat0,
+    lon0,
+    h0,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[ndarray, ndarray, ndarray]:
+) -> tuple:
     """
     Parameters
     ----------
