@@ -1,25 +1,14 @@
 """geodetic transforms to auxilary coordinate systems involving latitude"""
 
 from __future__ import annotations
-import typing
+
+from math import pi
 
 from .ellipsoid import Ellipsoid
-from .utils import sanitize, sign
+from .mathfun import atan, radians, degrees, tan, sin, cos, asinh, atanh, exp, sqrt, inf, sign
+from .utils import sanitize
 from . import rcurve
 
-try:
-    from numpy import radians, degrees, tan, sin, cos, exp, pi, sqrt, inf
-    from numpy import arctan as atan, arcsinh as asinh, arctanh as atanh  # noqa: A001
-
-    use_numpy = True
-except ImportError:
-    from math import atan, radians, degrees, tan, sin, cos, asinh, atanh, exp, pi, sqrt, inf  # type: ignore
-
-    use_numpy = False
-
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
-
 COS_EPS = 1e-9  # tolerance for angles near abs([90, 270])
 
 __all__ = [
@@ -41,11 +30,11 @@ __all__ = [
 
 
 def geoc2geod(
-    geocentric_lat: ndarray,
-    geocentric_distance: ndarray,
+    geocentric_lat,
+    geocentric_distance,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> float:
+):
     """
     convert geocentric latitude to geodetic latitude, consider mean sea level altitude
 
@@ -81,15 +70,13 @@ def geoc2geod(
     geodetic_lat = (
         geocentric_lat
         + (sin(2 * geocentric_lat) / r) * ell.flattening
-        + ((1 / r ** 2 + 1 / (4 * r)) * sin(4 * geocentric_lat)) * ell.flattening ** 2
+        + ((1 / r**2 + 1 / (4 * r)) * sin(4 * geocentric_lat)) * ell.flattening**2
     )
 
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2geocentric(
-    geodetic_lat: ndarray, alt_m: float, ell: Ellipsoid = None, deg: bool = True
-) -> ndarray:
+def geodetic2geocentric(geodetic_lat, alt_m, ell: Ellipsoid = None, deg: bool = True):
     """
     convert geodetic latitude to geocentric latitude on spheroid surface
 
@@ -120,7 +107,7 @@ def geodetic2geocentric(
     """
     geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
     r = rcurve.transverse(geodetic_lat, ell, deg=False)
-    geocentric_lat = atan((1 - ell.eccentricity ** 2 * (r / (r + alt_m))) * tan(geodetic_lat))
+    geocentric_lat = atan((1 - ell.eccentricity**2 * (r / (r + alt_m))) * tan(geodetic_lat))
 
     return degrees(geocentric_lat) if deg else geocentric_lat
 
@@ -128,9 +115,7 @@ def geodetic2geocentric(
 geod2geoc = geodetic2geocentric
 
 
-def geocentric2geodetic(
-    geocentric_lat: ndarray, alt_m: float, ell: Ellipsoid = None, deg: bool = True
-) -> ndarray:
+def geocentric2geodetic(geocentric_lat, alt_m, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from geocentric latitude to geodetic latitude
 
@@ -161,14 +146,12 @@ def geocentric2geodetic(
     """
     geocentric_lat, ell = sanitize(geocentric_lat, ell, deg)
     r = rcurve.transverse(geocentric_lat, ell, deg=False)
-    geodetic_lat = atan(tan(geocentric_lat) / (1 - ell.eccentricity ** 2 * (r / (r + alt_m))))
+    geodetic_lat = atan(tan(geocentric_lat) / (1 - ell.eccentricity**2 * (r / (r + alt_m))))
 
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2isometric(
-    geodetic_lat: float | ndarray, ell: Ellipsoid = None, deg: bool = True
-) -> float:
+def geodetic2isometric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     computes isometric latitude on an ellipsoid
 
@@ -228,7 +211,7 @@ def geodetic2isometric(
         return isometric_lat
 
 
-def isometric2geodetic(isometric_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def isometric2geodetic(isometric_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from isometric latitude to geodetic latitude
 
@@ -264,7 +247,7 @@ def isometric2geodetic(isometric_lat: ndarray, ell: Ellipsoid = None, deg: bool
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def conformal2geodetic(conformal_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def conformal2geodetic(conformal_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from conformal latitude to geodetic latitude
 
@@ -293,10 +276,10 @@ def conformal2geodetic(conformal_lat: ndarray, ell: Ellipsoid = None, deg: bool
     conformal_lat, ell = sanitize(conformal_lat, ell, deg)
 
     e = ell.eccentricity
-    f1 = e ** 2 / 2 + 5 * e ** 4 / 24 + e ** 6 / 12 + 13 * e ** 8 / 360
-    f2 = 7 * e ** 4 / 48 + 29 * e ** 6 / 240 + 811 * e ** 8 / 11520
-    f3 = 7 * e ** 6 / 120 + 81 * e ** 8 / 1120
-    f4 = 4279 * e ** 8 / 161280
+    f1 = e**2 / 2 + 5 * e**4 / 24 + e**6 / 12 + 13 * e**8 / 360
+    f2 = 7 * e**4 / 48 + 29 * e**6 / 240 + 811 * e**8 / 11520
+    f3 = 7 * e**6 / 120 + 81 * e**8 / 1120
+    f4 = 4279 * e**8 / 161280
 
     geodetic_lat = (
         conformal_lat
@@ -309,7 +292,7 @@ def conformal2geodetic(conformal_lat: ndarray, ell: Ellipsoid = None, deg: bool
     return degrees(geodetic_lat) if deg else geodetic_lat
 
 
-def geodetic2conformal(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def geodetic2conformal(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from geodetic latitude to conformal latitude
 
@@ -355,9 +338,7 @@ def geodetic2conformal(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
 
 
 # %% rectifying
-def geodetic2rectifying(
-    geodetic_lat: float | ndarray, ell: Ellipsoid = None, deg: bool = True
-) -> float:
+def geodetic2rectifying(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from geodetic latitude to rectifying latitude
 
@@ -387,10 +368,10 @@ def geodetic2rectifying(
     geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
 
     n = ell.thirdflattening
-    f1 = 3 * n / 2 - 9 * n ** 3 / 16
-    f2 = 15 * n ** 2 / 16 - 15 * n ** 4 / 32
-    f3 = 35 * n ** 3 / 48
-    f4 = 315 * n ** 4 / 512
+    f1 = 3 * n / 2 - 9 * n**3 / 16
+    f2 = 15 * n**2 / 16 - 15 * n**4 / 32
+    f3 = 35 * n**3 / 48
+    f4 = 315 * n**4 / 512
 
     rectifying_lat = (
         geodetic_lat
@@ -403,9 +384,7 @@ def geodetic2rectifying(
     return degrees(rectifying_lat) if deg else rectifying_lat
 
 
-def rectifying2geodetic(
-    rectifying_lat: ndarray, ell: Ellipsoid = None, deg: bool = True
-) -> ndarray:
+def rectifying2geodetic(rectifying_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from rectifying latitude to geodetic latitude
 
@@ -434,10 +413,10 @@ def rectifying2geodetic(
     rectifying_lat, ell = sanitize(rectifying_lat, ell, deg)
 
     n = ell.thirdflattening
-    f1 = 3 * n / 2 - 27 * n ** 3 / 32
-    f2 = 21 * n ** 2 / 16 - 55 * n ** 4 / 32
-    f3 = 151 * n ** 3 / 96
-    f4 = 1097 * n ** 4 / 512
+    f1 = 3 * n / 2 - 27 * n**3 / 32
+    f2 = 21 * n**2 / 16 - 55 * n**4 / 32
+    f3 = 151 * n**3 / 96
+    f4 = 1097 * n**4 / 512
 
     geodetic_lat = (
         rectifying_lat
@@ -451,7 +430,7 @@ def rectifying2geodetic(
 
 
 # %% authalic
-def geodetic2authalic(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def geodetic2authalic(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from geodetic latitude to authalic latitude
 
@@ -481,9 +460,9 @@ def geodetic2authalic(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
     geodetic_lat, ell = sanitize(geodetic_lat, ell, deg)
 
     e = ell.eccentricity
-    f1 = e ** 2 / 3 + 31 * e ** 4 / 180 + 59 * e ** 6 / 560
-    f2 = 17 * e ** 4 / 360 + 61 * e ** 6 / 1260
-    f3 = 383 * e ** 6 / 45360
+    f1 = e**2 / 3 + 31 * e**4 / 180 + 59 * e**6 / 560
+    f2 = 17 * e**4 / 360 + 61 * e**6 / 1260
+    f3 = 383 * e**6 / 45360
 
     authalic_lat = (
         geodetic_lat
@@ -495,7 +474,7 @@ def geodetic2authalic(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
     return degrees(authalic_lat) if deg else authalic_lat
 
 
-def authalic2geodetic(authalic_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def authalic2geodetic(authalic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from authalic latitude to geodetic latitude
 
@@ -523,9 +502,9 @@ def authalic2geodetic(authalic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
     """
     authalic_lat, ell = sanitize(authalic_lat, ell, deg)
     e = ell.eccentricity
-    f1 = e ** 2 / 3 + 31 * e ** 4 / 180 + 517 * e ** 6 / 5040
-    f2 = 23 * e ** 4 / 360 + 251 * e ** 6 / 3780
-    f3 = 761 * e ** 6 / 45360
+    f1 = e**2 / 3 + 31 * e**4 / 180 + 517 * e**6 / 5040
+    f2 = 23 * e**4 / 360 + 251 * e**6 / 3780
+    f3 = 761 * e**6 / 45360
 
     geodetic_lat = (
         authalic_lat
@@ -538,7 +517,7 @@ def authalic2geodetic(authalic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
 
 
 # %% parametric
-def geodetic2parametric(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def geodetic2parametric(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from geodetic latitude to parametric latitude
 
@@ -572,9 +551,7 @@ def geodetic2parametric(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool
     return degrees(parametric_lat) if deg else parametric_lat
 
 
-def parametric2geodetic(
-    parametric_lat: ndarray, ell: Ellipsoid = None, deg: bool = True
-) -> ndarray:
+def parametric2geodetic(parametric_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     converts from parametric latitude to geodetic latitude
 
