@@ -1,23 +1,15 @@
 """compute radii of curvature for an ellipsoid"""
 
 from __future__ import annotations
-import typing
-
-try:
-    from numpy import sin, cos, sqrt
-except ImportError:
-    from math import sin, cos, sqrt  # type: ignore
 
 from .ellipsoid import Ellipsoid
+from .mathfun import cos, sin, sqrt
 from .utils import sanitize
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
-
 __all__ = ["parallel", "meridian", "transverse", "geocentric_radius"]
 
 
-def geocentric_radius(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def geocentric_radius(geodetic_lat, ell: Ellipsoid = None, deg: bool = True):
     """
     compute geocentric radius at geodetic latitude
 
@@ -27,8 +19,8 @@ def geocentric_radius(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
 
     return sqrt(
         (
-            (ell.semimajor_axis ** 2 * cos(geodetic_lat)) ** 2
-            + (ell.semiminor_axis ** 2 * sin(geodetic_lat)) ** 2
+            (ell.semimajor_axis**2 * cos(geodetic_lat)) ** 2
+            + (ell.semiminor_axis**2 * sin(geodetic_lat)) ** 2
         )
         / (
             (ell.semimajor_axis * cos(geodetic_lat)) ** 2
@@ -37,7 +29,7 @@ def geocentric_radius(geodetic_lat: ndarray, ell: Ellipsoid = None, deg: bool =
     )
 
 
-def parallel(lat: float | ndarray, ell: Ellipsoid = None, deg: bool = True) -> float:
+def parallel(lat, ell: Ellipsoid = None, deg: bool = True) -> float:
     """
     computes the radius of the small circle encompassing the globe at the specified latitude
 
@@ -63,7 +55,7 @@ def parallel(lat: float | ndarray, ell: Ellipsoid = None, deg: bool = True) -> f
     return cos(lat) * transverse(lat, ell, deg=False)
 
 
-def meridian(lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def meridian(lat, ell: Ellipsoid = None, deg: bool = True):
     """computes the meridional radius of curvature for the ellipsoid
 
     like Matlab rcurve('meridian', ...)
@@ -85,12 +77,12 @@ def meridian(lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
 
     lat, ell = sanitize(lat, ell, deg)
 
-    f1 = ell.semimajor_axis * (1 - ell.eccentricity ** 2)
+    f1 = ell.semimajor_axis * (1 - ell.eccentricity**2)
     f2 = 1 - (ell.eccentricity * sin(lat)) ** 2
-    return f1 / sqrt(f2 ** 3)
+    return f1 / sqrt(f2**3)
 
 
-def transverse(lat: float | ndarray, ell: Ellipsoid = None, deg: bool = True) -> ndarray:
+def transverse(lat, ell: Ellipsoid = None, deg: bool = True):
     """computes the radius of the curve formed by a plane
     intersecting the ellipsoid at the latitude which is
     normal to the surface of the ellipsoid
