@@ -1,20 +1,17 @@
 """ compute radii of auxiliary spheres"""
 
 from __future__ import annotations
-import typing
 
 try:
-    from numpy import radians, sin, cos, log, sqrt, degrees, asarray
+    from numpy import asarray
 except ImportError:
-    from math import radians, sin, cos, log, sqrt, degrees  # type: ignore
+    pass
 
 from .ellipsoid import Ellipsoid
+from .mathfun import radians, sin, cos, log, sqrt, degrees
 from . import rcurve
 from .vincenty import vdist
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
-
 __all__ = [
     "eqavol",
     "authalic",
@@ -44,7 +41,7 @@ def eqavol(ell: Ellipsoid = None) -> float:
 
     f = ell.flattening
 
-    return ell.semimajor_axis * (1 - f / 3 - f ** 2 / 9)
+    return ell.semimajor_axis * (1 - f / 3 - f**2 / 9)
 
 
 def authalic(ell: Ellipsoid = None) -> float:
@@ -66,8 +63,8 @@ def authalic(ell: Ellipsoid = None) -> float:
     e = ell.eccentricity
 
     if e > 0:
-        f1 = ell.semimajor_axis ** 2 / 2
-        f2 = (1 - e ** 2) / (2 * e)
+        f1 = ell.semimajor_axis**2 / 2
+        f2 = (1 - e**2) / (2 * e)
         f3 = log((1 + e) / (1 - e))
         return sqrt(f1 * (1 + f2 * f3))
     else:
@@ -93,13 +90,13 @@ def rectifying(ell: Ellipsoid = None) -> float:
 
 
 def euler(
-    lat1: ndarray,
-    lon1: ndarray,
-    lat2: ndarray,
-    lon2: ndarray,
+    lat1,
+    lon1,
+    lat2,
+    lon2,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> ndarray:
+):
     """computes the Euler radii of curvature at the midpoint of the
      great circle arc defined by the endpoints (lat1,lon1) and (lat2,lon2)
 
@@ -143,7 +140,7 @@ def euler(
     return rho * nu / den
 
 
-def curve(lat: ndarray, ell: Ellipsoid = None, deg: bool = True, method: str = "mean") -> ndarray:
+def curve(lat, ell: Ellipsoid = None, deg: bool = True, method: str = "mean"):
     """computes the arithmetic average of the transverse and meridional
     radii of curvature at a specified latitude point
 
@@ -200,7 +197,7 @@ def triaxial(ell: Ellipsoid = None, method: str = "mean") -> float:
     if method == "mean":
         return (2 * ell.semimajor_axis + ell.semiminor_axis) / 3
     elif method == "norm":
-        return (ell.semimajor_axis ** 2 * ell.semiminor_axis) ** (1 / 3)
+        return (ell.semimajor_axis**2 * ell.semiminor_axis) ** (1 / 3)
     else:
         raise ValueError("method must be mean or norm")
 
