@@ -3,44 +3,30 @@ Vincenty's methods for computing ground distance and reckoning
 """
 
 from __future__ import annotations
-import typing
+
 import logging
 from math import nan, pi
 from copy import copy
 
 try:
-    from numpy import (
-        atleast_1d,
-        sqrt,
-        tan,
-        sin,
-        cos,
-        isnan,
-        arctan as atan,
-        arctan2 as atan2,
-        arcsin as asin,
-        radians,
-        degrees,
-    )
+    from numpy import atleast_1d
 except ImportError:
-    from math import sqrt, tan, sin, cos, isnan, atan, atan2, asin, radians, degrees  # type: ignore
+    pass
 
+from .mathfun import sqrt, tan, sin, cos, isnan, atan, atan2, asin, radians, degrees, sign
 from .ellipsoid import Ellipsoid
-from .utils import sign
 
-if typing.TYPE_CHECKING:
-    from numpy import ndarray
 
 __all__ = ["vdist", "vreckon", "track2"]
 
 
 def vdist(
-    Lat1: float | ndarray,
-    Lon1: float | ndarray,
-    Lat2: float | ndarray,
-    Lon2: float | ndarray,
+    Lat1,
+    Lon1,
+    Lat2,
+    Lon2,
     ell: Ellipsoid = None,
-) -> tuple[ndarray, ndarray]:
+) -> tuple:
     """
     Using the reference ellipsoid, compute the distance between two points
     within a few millimeters of accuracy, compute forward azimuth,
@@ -211,7 +197,7 @@ def vdist(
         C = f / 16 * cos(alpha) ** 2 * (4 + f * (4 - 3 * cos(alpha) ** 2))
 
         lamb = L + (1 - C) * f * sin(alpha) * (
-            sigma + C * sin(sigma) * (cos2sigmam + C * cos(sigma) * (-1 + 2.0 * cos2sigmam ** 2))
+            sigma + C * sin(sigma) * (cos2sigmam + C * cos(sigma) * (-1 + 2.0 * cos2sigmam**2))
         )
         # print(f'then, lambda(21752) = {lamb[21752],20})
         # correct for convergence failure for essentially antipodal points
@@ -233,7 +219,7 @@ def vdist(
         except AttributeError:
             notdone = abs(lamb - lambdaold) > 1e-12
 
-    u2 = cos(alpha) ** 2 * (a ** 2 - b ** 2) / b ** 2
+    u2 = cos(alpha) ** 2 * (a**2 - b**2) / b**2
     A = 1 + u2 / 16384 * (4096 + u2 * (-768 + u2 * (320 - 175 * u2)))
     B = u2 / 1024 * (256 + u2 * (-128 + u2 * (74 - 47 * u2)))
     deltasigma = (
@@ -244,8 +230,8 @@ def vdist(
             + B
             / 4
             * (
-                cos(sigma) * (-1 + 2 * cos2sigmam ** 2)
-                - B / 6 * cos2sigmam * (-3 + 4 * sin(sigma) ** 2) * (-3 + 4 * cos2sigmam ** 2)
+                cos(sigma) * (-1 + 2 * cos2sigmam**2)
+                - B / 6 * cos2sigmam * (-3 + 4 * sin(sigma) ** 2) * (-3 + 4 * cos2sigmam**2)
             )
         )
     )
@@ -277,8 +263,12 @@ def vdist(
 
 
 def vreckon(
-    Lat1: float | ndarray, Lon1: float | ndarray, Rng: ndarray, Azim: ndarray, ell: Ellipsoid = None
-) -> tuple[ndarray, ndarray]:
+    Lat1,
+    Lon1,
+    Rng,
+    Azim,
+    ell: Ellipsoid = None,
+) -> tuple:
     """
     This is the Vincenty "forward" solution.
 
@@ -376,12 +366,12 @@ def vreckon(
     cosAlpha1 = cos(alpha1)
 
     tanU1 = (1 - f) * tan(lat1)
-    cosU1 = 1 / sqrt(1 + tanU1 ** 2)
+    cosU1 = 1 / sqrt(1 + tanU1**2)
     sinU1 = tanU1 * cosU1
     sigma1 = atan2(tanU1, cosAlpha1)
     sinAlpha = cosU1 * sinAlpha1
     cosSqAlpha = 1 - sinAlpha * sinAlpha
-    uSq = cosSqAlpha * (a ** 2 - b ** 2) / b ** 2
+    uSq = cosSqAlpha * (a**2 - b**2) / b**2
     A = 1 + uSq / 16384 * (4096 + uSq * (-768 + uSq * (320 - 175 * uSq)))
     B = uSq / 1024 * (256 + uSq * (-128 + uSq * (74 - 47 * uSq)))
 
@@ -428,7 +418,7 @@ def vreckon(
     tmp = sinU1 * sinSigma - cosU1 * cosSigma * cosAlpha1
     lat2 = atan2(
         sinU1 * cosSigma + cosU1 * sinSigma * cosAlpha1,
-        (1 - f) * sqrt(sinAlpha * sinAlpha + tmp ** 2),
+        (1 - f) * sqrt(sinAlpha * sinAlpha + tmp**2),
     )
 
     lamb = atan2(sinSigma * sinAlpha1, cosU1 * cosSigma - sinU1 * sinSigma * cosAlpha1)
@@ -457,14 +447,14 @@ def vreckon(
 
 
 def track2(
-    lat1: ndarray,
-    lon1: ndarray,
-    lat2: ndarray,
-    lon2: ndarray,
+    lat1,
+    lon1,
+    lat2,
+    lon2,
     ell: Ellipsoid = None,
     npts: int = 100,
     deg: bool = True,
-) -> tuple[list[ndarray], list[ndarray]]:
+) -> tuple[list, list]:
     """
     computes great circle tracks starting at the point lat1, lon1 and ending at lat2, lon2
 
